@@ -2,8 +2,9 @@ use 5.14.0;
 
 package Map::Metro::Plugin::Map::Barcelona;
 
-our $VERSION = '0.1007'; # VERSION
 # ABSTRACT: Map::Metro map for Barcelona
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1008';
 
 use Moose;
 with 'Map::Metro::Plugin::Map';
@@ -30,9 +31,22 @@ __END__
 
 Map::Metro::Plugin::Map::Barcelona - Map::Metro map for Barcelona
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.16+-blue.svg" alt="Requires Perl 5.16+" />
+<a href="https://travis-ci.org/Csson/p5-Map-Metro-Barcelona"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Barcelona.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Map-Metro-Plugin-Map-Barcelona-0.1008"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Map-Metro-Plugin-Map-Barcelona/0.1008" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Map-Metro-Plugin-Map-Barcelona%200.1008"><img src="http://badgedepot.code301.com/badge/cpantesters/Map-Metro-Plugin-Map-Barcelona/0.1008" alt="CPAN Testers result" /></a>
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.1007, released 2015-02-02.
+Version 0.1008, released 2019-03-31.
 
 =head1 SYNOPSIS
 
@@ -94,7 +108,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
